##
## Fox (2013) Analysis Multidimesional RIRT CAPS adn EAQ Data
##
## Analysis CAPS and AEQ Data

library(MASS)

## Load Data Objects 
load("DataObjects.Rdata")

## DATA Object

#school 1=Elon, 2=GTCC, 3=Wake Forest, 4=UNCG
#group  1 = Treatment (RRT), 2 = Control (DQ)
#age	(continuous)
#gender  1=Male,  2=Female
#race	  1=American Indian/Alaskan Native, 2=Hispanic, 3=Asian/Pacific Islander,   4=White (non-Hispanic), 5=Black (non-Hispanic), 6=(other)	  
#RR for NAs

N <- 793
K <- 17
Y <- as.matrix(data[,6:22])

## NOTE! when X  vector of ones length N only intercept  
## Specification of X is required

X <- as.matrix(data[,c(2,4)]) #DQ = 1, Female = 1
X <- X - 1
RR <- matrix(0,ncol=K,nrow=N)
RR[which(X[,1]==0),1:K] <- 1

## apply(RR,2,sum) #check

## X : Intercept, RRT (DQ=1), and Gender (Female = 1).
X <- cbind(1,X) ## intercept

## load MIRT-RR script
source("MIRT-RR.REAL.R")



## Run analysis Two and Three Factors ##

#### Two Factors #####

outq2 	<- MIRTRR(Y,X,Q=2,XG=50000,RR)  ## RR + gender


aa <- matrix(apply(outq2$MA[5000:50000,],2,mean),ncol=2,nrow=K)
aa/sqrt(apply(aa**2,1,sum))

#thresholds
matrix(apply(outq2$Mbeta[10000:50000,],2,mean),nrow=K,ncol=4)

#SigmaP 
matrix(apply((outq2$MSigmaP[10000:50000,]),2,mean),ncol=2)
sqrt(matrix(apply((outq2$MSigmaP[10000:50000,]),2,var),ncol=2))

#Covariate Effects
apply(outq2$MBReg[10000:50000,,1],2,mean) 	#DQ Female effect 
sqrt(apply(outq2$MBReg[10000:50000,,1],2,var))  #DQ Female effect

apply(outq2$MBReg[10000:50000,,2],2,mean) 	#DQ Female effect 
sqrt(apply(outq2$MBReg[10000:50000,,1],2,var))  #DQ Female effect
plot(outq2$EAPtheta)

#loglik 
mean(outq2$Mloglik[10000:50000])*(-2)
plot(outq2$EAPtheta[,2], outq2n$loglik)


#### Three Factors ####

outq3n	<- MIRTRR(Y,X,Q=3,XG=50000,RR)  ## RR + gender

aa <- matrix(apply(outq3n$MA[20000:50000,],2,mean),ncol=3,nrow=K)
aa/sqrt(apply(aa**2,1,sum))

#SigmaP 
matrix(apply((outq3n$MSigmaP[10000:50000,]),2,mean),ncol=3)
sqrt(matrix(apply((outq3n$MSigmaP[10000:50000,]),2,var),ncol=3))

## Covariate Effects
## Force positive factor loadings, multiply theta with -1, multiply regression effects with -1  

apply(outq3n$MBReg[10000:50000,,1],2,mean) 	#socio #DQ Female effect 
sqrt(apply(outq3n$MBReg[10000:50000,,1],2,var))
 
apply(outq3n$MBReg[10000:50000,,2],2,mean) 	#AE #DQ Female effect 
sqrt(apply(outq3n$MBReg[10000:50000,,2],2,var))

apply(outq3n$MBReg[10000:50000,,3],2,mean) 	#Community scale #DQ Female effect  
sqrt(apply(outq3n$MBReg[10000:50000,,3],2,var))

plot(outq3n$Mloglik)
mean(outq3sch$Mloglik[10000:50000])*(-2)


## School Group

X3 <- matrix(0,ncol=3,nrow=N)
X3[which(data$SCHOOL==1),1] <- 1
X3[which(data$SCHOOL==2),2] <- 1
X3[which(data$SCHOOL==3),3] <- 1
X3[which(data$SCHOOL==4),1:3] <- -1
X31 <- matrix(c(X[,-3],X3),ncol=5,nrow=N)

#### Two Factors (RR and School) ####

outq2sch <- MIRTRR(Y,X31,Q=2,XG=50000,RR)

aa <- matrix(apply(outq2sch$MA[10000:50000,],2,mean),ncol=2,nrow=K)
aa/sqrt(apply(aa**2,1,sum))

#SigmaP 
matrix(apply((outq2sch$MSigmaP[10000:50000,]),2,mean),ncol=2)
sqrt(matrix(apply((outq2sch$MSigmaP[10000:50000,]),2,var),ncol=2))

## Covariate Effects
## Force positive factor loadings, multiply theta with -1, multiply regression effects with -1  

apply(outq2sch$MBReg[10000:50000,,1],2,mean) 	#Socio #DQ School effect 
sqrt(apply(outq2sch$MBReg[10000:50000,,1],2,var))
 
apply(outq2sch$MBReg[10000:50000,,2],2,mean) 	#AE #DQ School effect 
sqrt(apply(outq2sch$MBReg[10000:50000,,2],2,var))

plot(outq2sch$Mloglik)
mean(outq2sch$Mloglik[10000:50000])*(-2)


#### Three Factors (RR and School) ####

outq3sch 	<- MIRTRR(Y,X31,Q=3,XG=50000,RR)

aa <- matrix(apply(outq3sch$MA[10000:50000,],2,mean),ncol=3,nrow=K)
aa/sqrt(apply(aa**2,1,sum))

#SigmaP 
matrix(apply((outq3sch$MSigmaP[10000:50000,]),2,mean),ncol=3)
sqrt(matrix(apply((outq3sch$MSigmaP[10000:50000,]),2,var),ncol=3))

## Covariate Effects
## Force positive factor loadings, multiply theta with -1, multiply regression effects with -1  

apply(outq3sch$MBReg[10000:50000,,1],2,mean) 	#Socio #DQ School effect 
sqrt(apply(outq3sch$MBReg[10000:50000,,1],2,var))
 
apply(outq3sch$MBReg[10000:50000,,2],2,mean) 	#AE #DQ School effect 
sqrt(apply(outq3sch$MBReg[10000:50000,,2],2,var))

apply(outq3sch$MBReg[10000:50000,,3],2,mean) 	#Community scale #DQ School effect  
sqrt(apply(outq3sch$MBReg[10000:50000,,3],2,var))

plot(outq3n$Mloglik)
mean(outq3$Mloglik[10000:50000])*(-2)


######################################################################################################
######################################################################################################
######################################################################################################
######################################################################################################









